/*
Example for Buck Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration PIC32 :
    
    MCU             : P32MX795F512L
    Dev. Board      : EasyPIC Fusion v7
    SW              : mikroC PRO for PIC32 v3.6.1

Description :

    A simple example of using Buck click, to set Vout to 3.3V or 5V just set the jumper on the appropriate place on the click.      
    The switching frequency  is regulated by MUX 4634 by setting pins A0 and A1 in following way:      
    A0 = 0 and A1 = 0 for 0.4 MHz	  	 
    A0 = 0 and A1 = 1 for 1.2 MHz	 	 
    A0 = 1 and A1 = 0 for 0.8 MHz	 	 
    A0 = 1 and A1 = 1 for 1.6 MHz	

*/

sbit MUX_A0_PIN at RC1_bit;
sbit MUX_A0_PIN_Direction at TRISC1_bit;

sbit BUCK_ENABLE_PIN at RC2_bit;
sbit BUCK_ENABLE_PIN_Direction at TRISC2_bit;

sbit MUX_A1_PIN at RD0_bit;
sbit MUX_A1_PIN_Direction at TRISD0_bit;

sbit PG_PIN at RE8_bit;
sbit PG_PIN_Direction at TRISE8_bit;

void systemInit()
{
    AD1PCFG = 0xFFFF; 
    UART2_Init(9600);  
}

void Buck_Init()
{
    MUX_A0_PIN_Direction = 0;
    BUCK_ENABLE_PIN_Direction = 0;
    MUX_A1_PIN_Direction = 0;
    PG_PIN_Direction = 1;
    BUCK_ENABLE_PIN = 1;
    MUX_A0_PIN = 0;
    MUX_A1_PIN = 0;   
}

void Buck_Task()
{
    if (PG_PIN == 1)
    {
        UART2_Write_text("Vout is within the final 8.4% of final regulation voltage");
        UART2_Write_Text( "\r\n" );
        delay_ms(1000);
    }
}

void main()
{
    systemInit();
    Buck_Init();

    while( 1 )
    {
    	Buck_Task();
    }
}